package main

import (
	"fmt"
	"github.com/astaxie/beego/logs"
	_ "hongze/hongze_cygx/routers"
	"hongze/hongze_cygx/services"
	"hongze/hongze_cygx/utils"
	"runtime"
	"time"

	"github.com/astaxie/beego/context"
	"github.com/astaxie/beego"
)

func main() {
	if beego.BConfig.RunMode == "dev" {
		beego.BConfig.WebConfig.DirectoryIndex = true
		beego.BConfig.WebConfig.StaticDir["/swagger"] = "swagger"
	}
	go services.Task()

	beego.BConfig.RecoverFunc = Recover
	beego.Run()
}


func Recover(ctx *context.Context) {
	if err := recover(); err != nil {
		if err == beego.ErrAbort {
			return
		}
		if !beego.BConfig.RecoverPanic {
			panic(err)
		}
		stack := ""
		msg := fmt.Sprintf("The request url is  %v", ctx.Input.URL())
		stack += msg + "</br>"
		logs.Critical(msg)
		msg = fmt.Sprintf("The request data is %v", string(ctx.Input.RequestBody))
		stack += msg + "</br>"
		logs.Critical(msg)
		msg = fmt.Sprintf("Handler crashed with error %v", err)
		stack += msg + "</br>"
		logs.Critical(msg)
		for i := 1; ; i++ {
			_, file, line, ok := runtime.Caller(i)
			if !ok {
				break
			}
			logs.Critical(fmt.Sprintf("%s:%d", file, line))
			stack = stack + fmt.Sprintln(fmt.Sprintf("%s:%d</br>", file, line))
		}
		go utils.SendEmail(utils.APPNAME+"崩了"+time.Now().Format("2006-01-02 15:04:05"), stack, utils.EmailSendToUsers)
	}
	return
}