package models

import (
	"rdluck_tools/orm"
)

type CygxArticle struct {
	Id               int    `orm:"column(id);pk"`
	ArticleId        int    `description:"文章id"`
	Title            string `description:"标题"`
	TitleEn          string `description:"英文标题 "`
	UpdateFrequency  string `description:"更新周期"`
	CreateDate       string `description:"创建时间"`
	PublishDate      string `description:"发布时间"`
	Body             string `description:"内容"`
	BodyText         string `description:"内容"`
	Abstract         string `description:"摘要"`
	CategoryName     string `description:"一级分类"`
	SubCategoryName  string `description:"二级分类"`
	PublishStatus    int    `description:"发布状态"`
	CategoryId       int    `description:"分类id"`
	ExpertBackground string `description:"专家背景"`
	ExpertNumber     string `description:"专家编号"`
	InterviewDate    string `description:"访谈日期"`
	Department       string `description:"作者"`
	ArticleIdMd5     string `description:"ID，md5值"`
	IsClass          int    `description:"是否归类，1是，0否"`
	IsSummary        int    `description:"是否是纪要库，1是，0否"`
	IsReport         int    `description:"是否属于报告，1是，0否"`
	ReportType       int    `description:"报告类型，1行业报告，2产业报告,0无"`
}

//新增文章
func AddCygxArticle(item *CygxArticle) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

type HomeArticle struct {
	ArticleId        int    `description:"文章id"`
	Title            string `description:"标题"`
	TitleEn          string `description:"英文标题 "`
	UpdateFrequency  string `description:"更新周期"`
	CreateDate       string `description:"创建时间"`
	PublishDate      string `description:"发布时间"`
	Body             string `description:"内容"`
	Abstract         string `description:"摘要"`
	CategoryName     string `description:"一级分类"`
	SubCategoryName  string `description:"二级分类"`
	ExpertBackground string `description:"专家背景"`
}

type ArticleDetail struct {
	ArticleId            int    `description:"报告id"`
	Title                string `description:"标题"`
	TitleEn              string `description:"英文标题 "`
	UpdateFrequency      string `description:"更新周期"`
	CreateDate           string `description:"创建时间"`
	PublishDate          string `description:"发布时间"`
	Body                 string `description:"内容"`
	Abstract             string `description:"摘要"`
	CategoryName         string `description:"一级分类"`
	SubCategoryName      string `description:"二级分类"`
	IsCollect            bool   `description:"是否收藏:true，已收藏，false:未收藏"`
	IsInterviewApply     bool   `description:"是否申请访谈:true，已申请，false:未申请"`
	BodyText             string `description:"内容"`
	InterviewApplyStatus string `description:"当前访谈申请状态：'待邀请','待访谈','已完成','已取消'"`
	InterviewDate        string `description:"访谈时间"`
	ExpertBackground     string `description:"专家背景"`
	ExpertNumber         string `description:"专家编号"`
	Department           string `description:"作者"`
	SellerMobile         string `description:"销售手机号"`
	SellerName           string `description:"销售名称"`
	ArticleIdMd5         string `description:"纪要id"`
}

func GetArticleDetailById(articleId int) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id = ? `
	err = o.Raw(sql, articleId).QueryRow(&item)
	return
}

func GetArticleDetailByIdMd5(articleIdMd5 string) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id_md5 = ? `
	err = o.Raw(sql, articleIdMd5).QueryRow(&item)
	return
}

func GetArticleDetailByIdStr(articleIdStr string) (items []*ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id IN(` + articleIdStr + `) `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

func GetArticlePermission(categoryName string) (item []*ChartPermission, err error) {
	o := orm.NewOrm()
	sql := ` SELECT b.* FROM cygx_permission_mapping AS a
			INNER JOIN chart_permission AS b ON a.chart_permission_id=b.chart_permission_id
			WHERE a.sub_category_name=? `
	_, err = o.Raw(sql, categoryName).QueryRows(&item)
	return
}

type ArticleDetailResp struct {
	Detail        *ArticleDetail
	HasPermission int `description:"1:有该行业权限,正常展示，2：无该行业权限，不存在权益客户下，3:无该品类权限,已提交过申请，4：无该行业权限,未提交过申请，5：潜在客户，未提交过申请，6：潜在客户,已提交过申请"`
	HasFree       int `description:"1:已付费(至少包含一个品类的权限)，2:未付费(没有任何品类权限)"`
}

func ModifyArticleExpert(articleId int, expertNumStr, expertContentStr, interviewDateStr, bodyText string) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE cygx_article SET expert_background=?,expert_number=?,interview_date=?,body_text=? WHERE article_id=? `
	_, err = o.Raw(sql, expertContentStr, expertNumStr, interviewDateStr, bodyText, articleId).Exec()
	return
}

type ArticleDetailTest struct {
	ArticleId int    `description:"报告id"`
	Title     string `description:"标题"`
	BodyText  string `description:"内容"`
	Body      string `json:"-" description:"内容"`
}

func GetArticleDetailTestById(articleId int) (item *ArticleDetailTest, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id = ? `
	err = o.Raw(sql, articleId).QueryRow(&item)
	return
}

func GetArticleAll() (item []*ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article `
	_, err = o.Raw(sql).QueryRows(&item)
	return
}

func ModifyArticleContent(articleId int, content, expertNumStr, expertContentStr, interviewDateStr string) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE cygx_article SET body=?,expert_background=?,expert_number=?,interview_date=? WHERE article_id=? `
	_, err = o.Raw(sql, content, expertContentStr, expertNumStr, interviewDateStr, articleId).Exec()
	return
}

type ElasticArticleDetail struct {
	ArticleId            int    `description:"报告id"`
	Title                string `description:"标题"`
	TitleEn              string `description:"英文标题 "`
	UpdateFrequency      string `description:"更新周期"`
	CreateDate           string `description:"创建时间"`
	PublishDate          string `description:"发布时间"`
	Abstract             string `description:"摘要"`
	CategoryName         string `description:"一级分类"`
	SubCategoryName      string `description:"二级分类"`
	IsCollect            bool   `description:"是否收藏:true，已收藏，false:未收藏"`
	IsInterviewApply     bool   `description:"是否申请访谈:true，已申请，false:未申请"`
	BodyText             string `description:"内容"`
	InterviewApplyStatus string `description:"当前访谈申请状态：'待邀请','待访谈','已完成','已取消'"`
	InterviewDate        string `description:"访谈时间"`
	ExpertBackground     string `description:"专家背景"`
	ExpertNumber         string `description:"专家编号"`
	Department           string `description:"作者"`
	SellerMobile         string `description:"销售手机号"`
	SellerName           string `description:"销售名称"`
	ArticleIdMd5         string `description:"纪要id"`
}

func GetArticleCountById(articleId int) (count int, err error) {
	o := orm.NewOrm()
	sql := `SELECT COUNT(1) AS count FROM cygx_article WHERE article_id = ? `
	err = o.Raw(sql, articleId).QueryRow(&count)
	return
}

type CygxArticles struct {
	Id               int    `orm:"column(id);pk"`
	ArticleId        int    `description:"文章id"`
	Title            string `description:"标题"`
	TitleEn          string `description:"英文标题 "`
	UpdateFrequency  string `description:"更新周期"`
	CreateDate       string `description:"创建时间"`
	PublishDate      string `description:"发布时间"`
	Body             string `description:"内容"`
	BodyText         string `description:"内容"`
	Abstract         string `description:"摘要"`
	CategoryName     string `description:"一级分类"`
	SubCategoryName  string `description:"二级分类"`
	PublishStatus    int    `description:"发布状态"`
	CategoryId       int    `description:"分类id"`
	ExpertBackground string `description:"专家背景"`
	ExpertNumber     string `description:"专家编号"`
	InterviewDate    string `description:"访谈日期"`
	Department       string `description:"作者"`
	ArticleIdMd5     string `description:"ID，md5值"`
	IsClass          int    `description:"是否归类，1是，0否"`
	IsSummary        int    `description:"是否是纪要库，1是，0否"`
	IsReport         int    `description:"是否属于报告，1是，0否"`
	ReportType       int    `description:"报告类型，1行业报告，2产业报告,0无"`
}

//新增文章
func AddCygxArticles(item *CygxArticle) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

func GetPermissionMappingById(categoryId int) (count int, err error) {
	o := orm.NewOrm()
	sql := `SELECT COUNT(1) AS count FROM cygx_permission_mapping WHERE category_id = ? `
	err = o.Raw(sql, categoryId).QueryRow(&count)
	return
}

func GetReportMappingById(categoryId int) (count int, err error) {
	o := orm.NewOrm()
	sql := `SELECT COUNT(1) AS count FROM cygx_report_mapping WHERE category_id = ? `
	err = o.Raw(sql, categoryId).QueryRow(&count)
	return
}

type ReportArticle struct {
	ArticleId        int    `description:"文章id"`
	Title            string `description:"标题"`
	TitleEn          string `description:"英文标题 "`
	UpdateFrequency  string `description:"更新周期"`
	CreateDate       string `description:"创建时间"`
	PublishDate      string `description:"发布时间"`
	Body             string `description:"内容"`
	Abstract         string `description:"摘要"`
	CategoryName     string `description:"一级分类"`
	SubCategoryName  string `description:"二级分类"`
	ExpertBackground string `description:"专家背景"`
	IsRed            bool   `description:"是否标记红点"`
}
