package models

import (
	"rdluck_tools/orm"
	"time"
)

type UserRecord struct {
	UserRecordId   int       `orm:"column(user_record_id);pk"`
	OpenId         string    `description:"用户openid，最大长度：32"`
	UnionId        string    `description:"用户unionid，最大长度：64"`
	Subscribe      int       `description:"是否关注"`
	NickName       string    `descritpion:"用户昵称，最大长度：32"`
	RealName       string    `descritpion:"用户实际名称，最大长度：32"`
	BindAccount    string    `descritpion:"绑定时的账号，最大长度：128"`
	Sex            int       `descritpion:"普通用户性别，1为男性，2为女性"`
	Province       string    `description:"普通用户个人资料填写的省份,最大长度：30"`
	City           string    `description:"普通用户个人资料填写的城市,最大长度：30"`
	Country        string    `description:"国家，如中国为CN,最大长度：30"`
	Headimgurl     string    `description:"用户第三方（微信）头像,最大长度：512"`
	CreateTime     time.Time `description:"创建时间，关系添加时间、用户授权时间"`
	CreatePlatform int       `description:"注册平台,1:日度点评公众号,2:管理后台，3：pc端网站,4:查研观向小程序；默认：1"`
	SessionKey     string    `description:"微信小程序会话密钥，最大长度：255"`
	UserId         int       `description:"用户id"`
}

//根据openid获取用户关系
func GetUserRecordByOpenId(openId string) (item *UserRecord, err error) {
	sql := `SELECT * FROM user_record WHERE open_id=? `
	err = orm.NewOrm().Raw(sql, openId).QueryRow(&item)
	return
}

//根据用户id和平台id获取用户关系
func GetUserRecordByUserId(userId, platform int) (item *UserRecord, err error) {
	sql := `SELECT * FROM user_record WHERE user_id=? AND create_platform = ?`
	err = orm.NewOrm().Raw(sql, userId, platform).QueryRow(&item)
	return
}

//添加用户关系
func AddUserRecord(record *UserRecord) (recordId int64, err error) {
	o := orm.NewOrm()
	recordId, err = o.Insert(record)
	return
}

//根据openid绑定用户关系
func BindUserRecordByOpenid(userId int, openId, bindAccount string) (err error) {
	o := orm.NewOrm()
	msql := " UPDATE user_record SET user_id = ?,bind_account=? WHERE open_id = ? "
	_, err = o.Raw(msql, userId, bindAccount, openId).Exec()
	return
}

//修改用户微信信息
func ModifyUserRecordInfo(openId, nickName, headimgUrl, city, province, country, sessionKey string, sex, userId int) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE user_record SET nick_name=?,headimgurl=?,sex=?,city=?,province=?,country=?,session_key=? WHERE user_id=? and open_id=? `
	_, err = o.Raw(sql, nickName, headimgUrl, sex, city, province, country, sessionKey, userId, openId).Exec()
	return
}

//修改用户微信信息
func ModifyUserRecordByDetail(openId, unionId, nickName, headimgUrl, city, province, country string, sex, userId int) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE user_record SET union_id=?, nick_name=?,headimgurl=?,sex=?,city=?,province=?,country=? WHERE user_id=? and open_id=? `
	_, err = o.Raw(sql, unionId, nickName, headimgUrl, sex, city, province, country, userId, openId).Exec()
	return
}

//修改用户微信信息
func ModifyUserRecordSessionKey(openId, sessionKey string) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE user_record SET session_key=? WHERE open_id=? `
	_, err = o.Raw(sql, sessionKey, openId).Exec()
	return
}

//根据用户id和平台id获取用户关系
func GetUserRecordByMobile(platform int, bindAccount string) (item *UserRecord, err error) {
	sql := `SELECT * FROM user_record WHERE create_platform=? AND bind_account = ?`
	err = orm.NewOrm().Raw(sql, platform, bindAccount).QueryRow(&item)
	return
}

//获取该用户第一个的 三方信息（微信头像信息）
func GetUserThirdRecordByUserId(userId int)  (item *UserRecord, err error) {
	sql := `SELECT * FROM user_record WHERE user_id = ? order by user_record_id asc`
	err = orm.NewOrm().Raw(sql, userId).QueryRow(&item)
	return
}
