package models

import (
	"rdluck_tools/orm"
	"time"
)

type WxUser struct {
	UserId           int       `orm:"column(user_id);pk"`
	OpenId           string    `description:"open_id"`
	UnionId          string    `description:"union_id"`
	Subscribe        string    `description:"是否关注"`
	CompanyId        int       `description:"客户id"`
	NickName         string    `description:"用户昵称"`
	RealName         string    `description:"用户实际名称"`
	UserCode         string    `description:"用户编码"`
	Mobile           string    `description:"手机号码"`
	BindAccount      string    `description:"绑定时的账号"`
	WxCode           string    `description:"微信号"`
	Profession       string    `description:"职业"`
	Email            string    `description:"邮箱"`
	Telephone        string    `description:"座机"`
	Sex              int       `description:"普通用户性别，1为男性，2为女性"`
	Province         string    `description:"普通用户个人资料填写的省份"`
	City             string    `description:"普通用户个人资料填写的城市"`
	Country          string    `description:"国家，如中国为CN"`
	SubscribeTime    int       `description:"关注时间"`
	Remark           string    `description:"备注"`
	Headimgurl       string    `description:"用户头像，最后一个数值代表正方形头像大小（有0、46、64、96、132数值可选，0代表640*640正方形头像），用户没有头像时该项为空"`
	Privilege        string    `description:"用户特权信息，json数组，如微信沃卡用户为（chinaunicom）"`
	Unionid          string    `description:"用户统一标识。针对一个微信开放平台帐号下的应用，同一用户的unionid是唯一的。"`
	FirstLogin       int       `description:"是否第一次登陆"`
	Enabled          int       `description:"是否可用"`
	CreatedTime      time.Time `description:"创建时间"`
	LastUpdatedTime  time.Time `description:"最新一次修改时间"`
	Seller           string    `description:"销售员"`
	Note             string    `description:"客户备份信息"`
	IsNote           int       `description:"是否备注过信息"`
	FromType         string    `description:"report' COMMENT 'report:研报，teleconference:电话会"`
	ApplyMethod      int       `description:"0:未申请，1:已付费客户申请试用，2:非客户申请试用"`
	RegisterTime     time.Time `description:"注册时间"`
	RegisterPlatform int       `description:"注册平台,1:微信端,2:PC网页端"`
	IsFreeLogin      bool      `description:"是否免登陆,true：免登陆,false:非免登陆"`
	LoginTime        time.Time `description:"最近一次登录时间"`
	SessionKey       string    `description:"微信小程序会话密钥"`
}

//添加用户信息
func AddWxUser(item *WxUser) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

type WxUserItem struct {
	UserId          int       `description:"用户id"`
	OpenId          string    `description:"open_id"`
	UnionId         string    `description:"union_id"`
	CompanyId       int       `description:"客户id"`
	NickName        string    `description:"用户昵称"`
	RealName        string    `description:"用户实际名称"`
	Mobile          string    `description:"手机号码"`
	BindAccount     string    `description:"绑定时的账号"`
	Email           string    `description:"邮箱"`
	Headimgurl      string    `description:"用户头像，最后一个数值代表正方形头像大小（有0、46、64、96、132数值可选，0代表640*640正方形头像），用户没有头像时该项为空"`
	ApplyMethod     int       `description:"0:未申请，1:已付费客户申请试用，2:非客户申请试用"`
	FirstLogin      int       `description:"是否第一次登陆"`
	IsFreeLogin     int       `description:"是否免登陆,true：免登陆,false:非免登陆"`
	LoginTime       time.Time `description:"登录时间"`
	CreatedTime     time.Time `description:"创建时间"`
	LastUpdatedTime time.Time `description:"最近一次修改时间"`
	SessionKey      string    `description:"微信小程序会话密钥"`
	CompanyName     string    `description:"公司名称"`
}

func GetWxUserItemByUnionid(unionid string) (item *WxUserItem, err error) {
	sql := `SELECT * FROM wx_user WHERE union_id=? `
	err = orm.NewOrm().Raw(sql, unionid).QueryRow(&item)
	return
}

func GetWxUserItemByUserId(userId int) (item *WxUserItem, err error) {
	sql := `SELECT a.*,b.company_name FROM wx_user AS a
			LEFT JOIN company AS b on a.company_id=b.company_id
			WHERE a.user_id=? `
	err = orm.NewOrm().Raw(sql, userId).QueryRow(&item)
	return
}

func GetWxUserItemByOpenId(openId string) (item *WxUserItem, err error) {
	sql := `SELECT * FROM wx_user WHERE open_id=? `
	err = orm.NewOrm().Raw(sql, openId).QueryRow(&item)
	return
}

type WxLoginResp struct {
	Authorization string
	UserId        int
	FirstLogin    int
	Headimgurl    string `description:"用户头像"`
	Mobile        string `description:"手机号"`
	Email         string `description:"邮箱"`
	CompanyName   string `description:"客户名称"`
	Status        string `description:"状态"`
	EndDate       string `description:"到期日期"`
	ProductName   string `description:"客户类型名称"`
}

type WxGetUserInfoReq struct {
	RawData       string `description:"rawData"`
	Signature     string `description:"signature"`
	EncryptedData string `description:"encryptedData"`
	Iv            string `description:"iv"`
}

//修改用户会话key
func ModifyWxUserSessionKey(sessionKey string, userId int) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE wx_user SET session_key=? WHERE user_id=? `
	_, err = o.Raw(sql, sessionKey, userId).Exec()
	return
}

//添加用户信息
func ModifyWxUserInfo(unionId, nickName, province, city, country, avatar string, gender, userId int) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE wx_user SET union_id=?,unionid=?,nick_name=?,sex=?,province=?,city=?,country=?,headimgurl=? WHERE user_id=? `
	_, err = o.Raw(sql, unionId, unionId, nickName, gender, province, city, country, avatar, userId).Exec()
	return
}

//修改用户会话key
func DeleteWxUserByUserId(userId int) (err error) {
	o := orm.NewOrm()
	sql := `DELETE FROM wx_user WHERE user_id=? `
	_, err = o.Raw(sql, userId).Exec()
	return
}

type WxGetUserInfoResp struct {
	//UsersId       int       `orm:"column(id);pk"`
	//Mobile        string    `description:"手机号"`
	//NickName      string    `description:"昵称"`
	//Gender        int       `description:"用户性别 1:男性,2:女性，0:未知(默认)"`
	//CreateTime    time.Time `description:"注册时间"`
	//ModifyTime    time.Time `description:"修改时间"`
	//AvatarUrl     string    `description:"头像地址"`
	//City          string    `description:"城市"`
	//Province      string    `description:"省"`
	//Country       string    `description:"国家"`
	//Language      string    `description:"语言"`
	//Appid         string    `description:"Appid"`
	//Timestamp     int64     `description:"时间戳"`
	Authorization string `description:"登陆凭证，后续接口调用时，带在请求头里面Key:Authorization"`
}

type WxGetPhoneNumberReq struct {
	EncryptedData string `description:"encryptedData"`
	Iv            string `description:"iv"`
}

func ModifyUsersMobile(usersId int, phoneNumber string) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE wx_user SET mobile=? WHERE user_id=? `
	_, err = o.Raw(sql, phoneNumber, usersId).Exec()
	return
}

type WxGetPhoneNumberResp struct {
	PhoneNumber     string `description:"用户绑定的手机号（国外手机号会有区号）"`
	PurePhoneNumber string `description:"没有区号的手机号"`
	CountryCode     string `description:"区号"`
}

func GetWxUserItemByMobile(mobile string) (item *WxUserItem, err error) {
	sql := `SELECT a.*,b.company_name FROM wx_user AS a
			LEFT JOIN company AS b on a.company_id=b.company_id
			WHERE a.mobile=? `
	err = orm.NewOrm().Raw(sql, mobile).QueryRow(&item)
	return
}

func GetWxUserItemByEmail(email string) (item *WxUserItem, err error) {
	sql := `SELECT * FROM wx_user WHERE email=? `
	err = orm.NewOrm().Raw(sql, email).QueryRow(&item)
	return
}
