package services

import (
	"fmt"
	"github.com/PuerkitoBio/goquery"
	"hongze/hongze_cygx/models"
	"html"
	"strings"
)

func GetReportContentSub(content string) (contentSub string, err error) {
	content = html.UnescapeString(content)
	doc, err := goquery.NewDocumentFromReader(strings.NewReader(content))
	if err != nil {
		fmt.Println("create doc err:", err.Error())
		return
	}
	n := 0
	doc.Find("p").Each(func(i int, s *goquery.Selection) {
		if n > 3 {
			return
		}
		n++
		phtml, err := s.Html()
		if err != nil {
			fmt.Println("get html err", err.Error())
			return
		}
		if s.Text() != "" || strings.Contains(phtml, "src") {
			contentSub = contentSub + "<p>" + phtml + "</p>"
		}
	})
	return
}

func GetReportContentTextSub(content string) (contentSub string, err error) {
	content = html.UnescapeString(content)
	doc, err := goquery.NewDocumentFromReader(strings.NewReader(content))
	//if err != nil {
	//	fmt.Println("create doc err:", err.Error())
	//	return
	//}
	//doc.Find("p").Each(func(i int, s *goquery.Selection) {
	//	pHtml, _ := s.Html()
	//	if strings.Contains(pHtml, "img") || strings.Contains(pHtml, "table") {
	//		s.Remove()
	//	}
	//})
	//if contentSub == "" || len(contentSub) < 200 {
	//	//m := 0
	//	doc.Find("span").Each(func(i int, s *goquery.Selection) {
	//		spanHtml, _ := s.Html()
	//		if strings.Contains(spanHtml, "img") || strings.Contains(spanHtml, "table") {
	//			s.Remove()
	//		}
	//	})
	//}
	docText := doc.Text()
	bodyRune := []rune(docText)
	bodyRuneLen := len(bodyRune)
	if bodyRuneLen > 200 {
		bodyRuneLen = 200
	}
	body := string(bodyRune[:bodyRuneLen])
	contentSub = body
	return
}

//解析文章内容
func GetArticleAll() {
	var err error
	defer func() {
		if err != nil {
			fmt.Println("err:", err.Error())
			return
		}
	}()
	list, err := models.GetArticleAll()
	if err != nil {
		return
	}
	for _, v := range list {
		fmt.Println(v.ArticleId, v.Title)
		FixArticleContent(v.ArticleId)
	}
}

//解析报告
func FixArticleContent(articleId int) {
	item, err := models.GetArticleDetailById(articleId)
	if err != nil {
		fmt.Println("GetArticleDetailById Err:" + err.Error())
		return
	}
	content := item.Body
	bodyText, _ := GetReportContentTextSub(content)
	content = html.UnescapeString(content)

	content = strings.Replace(content, "http", "https", -1)

	doc, err := goquery.NewDocumentFromReader(strings.NewReader(content))
	if err != nil {
		fmt.Println("create doc err:", err.Error())
		return
	}

	var expertNumArr []string
	var expertContentArr []string
	var interviewDateArr []string

	doc.Find("p").Each(func(i int, s *goquery.Selection) {
		contentTxt := s.Text()
		if strings.Contains(contentTxt, "#访谈时间：") || strings.Contains(contentTxt, "访谈时间：") {
			interviewDate := s.Next().Text()
			interviewDateArr = append(interviewDateArr, interviewDate)
		}
		if strings.Contains(contentTxt, "#专家评价") || strings.Contains(contentTxt, "专家评价") {
			expertContent := s.Next().Text()
			if expertContent == "" {
				expertContent = contentTxt
			}
			if expertContent != "" {
				rightIndex := strings.Index(expertContent, "）")
				if rightIndex == 0 {
					rightIndex = strings.Index(expertContent, ")")
				}
				if rightIndex > 0 {
					expertNum := expertContent[:rightIndex]
					expertNum = strings.Replace(expertNum, "（", "", -1)
					expertNum = strings.Replace(expertNum, "(", "", -1)
					expertNum = strings.Replace(expertNum, "专家评价", "", -1)
					if expertNum != "" {
						expertNumArr = append(expertNumArr, expertNum)
						rightIndex = rightIndex
						expertContentStr := expertContent[rightIndex:]
						expertContentStr = strings.Replace(expertContentStr, "）", "", -1)
						expertContentStr = strings.TrimLeft(expertContentStr, "：")
						expertContentStr = strings.TrimRight(expertContentStr, "（推荐")
						expertContentArr = append(expertContentArr, expertContentStr)
					}
				}
			}
		}
	})

	if len(expertContentArr) <= 0 {
		doc.Find("pre").Each(func(i int, pre *goquery.Selection) {
			pre.Find("span").Each(func(n int, span *goquery.Selection) {
				contentTxt := span.Text()
				if strings.Contains(contentTxt, "#专家评价") || strings.Contains(contentTxt, "专家评价") {
					span.Find("span").Each(func(m int, subspan *goquery.Selection) {
						subspanText := subspan.Text()
						if strings.Contains(subspanText, "专家评价") {
							expertContent := subspan.Next().Text()
							if expertContent != "" {
								rightIndex := strings.Index(expertContent, "）")
								if rightIndex == 0 {
									rightIndex = strings.Index(expertContent, ")")
								}
								if rightIndex > 0 {
									expertNum := expertContent[:rightIndex]
									expertNum = strings.Replace(expertNum, "（", "", -1)
									expertNum = strings.Replace(expertNum, "(", "", -1)
									expertNum = strings.Replace(expertNum, "专家评价", "", -1)
									if expertNum != "" {
										expertNumArr = append(expertNumArr, expertNum)
										rightIndex = rightIndex
										expertContentStr := expertContent[rightIndex:]
										expertContentStr = strings.Replace(expertContentStr, "）", "", -1)
										expertContentStr = strings.TrimLeft(expertContentStr, "：")
										expertContentStr = strings.TrimRight(expertContentStr, "（推荐")
										expertContentArr = append(expertContentArr, expertContentStr)
									}
								}
							}
						}

					})
				}

				span.Find("span").Each(func(k int, sspan *goquery.Selection) {
					sspanText := sspan.Text()
					if strings.Contains(sspanText, "访谈时间") {
						sspanText = strings.Replace(sspanText, "#访谈时间：", "", -1)
						sspanText = strings.Replace(sspanText, "访谈时间：", "", -1)
						sspanText = strings.Replace(sspanText, "\n", "", -1)
						sspanText = strings.Replace(sspanText, " ", "", -1)
						sspanText = strings.Trim(sspanText, " ")
						sspanText = sspanText[:10]
						interviewDate := sspanText
						if interviewDate != "" {
							interviewDateArr = append(interviewDateArr, interviewDate)
						}
					}
				})
			})
		})
	}

	if len(expertContentArr) <= 0 {
		doc.Find("span").Each(func(i int, span *goquery.Selection) {
			span.Find("strong").Each(func(n int, strong *goquery.Selection) {
				spanText := span.Text()
				strongText := strong.Text()
				if strings.Contains(strongText, "#专家评价") || strings.Contains(strongText, "专家评价") {
					expertContent := strong.Parents().Text()
					if expertContent != "" {
						rightIndex := strings.Index(expertContent, "）")
						if rightIndex == 0 {
							rightIndex = strings.Index(expertContent, ")")
						}
						if rightIndex > 0 {
							expertNum := expertContent[:rightIndex]
							expertNum = strings.Replace(expertNum, "（", "", -1)
							expertNum = strings.Replace(expertNum, "(", "", -1)
							expertNum = strings.Replace(expertNum, "专家评价", "", -1)
							expertNum = strings.Replace(expertNum, "#", "", -1)
							expertNum = strings.Replace(expertNum, "：", "", -1)
							expertNum = strings.Replace(expertNum, "\n", "", -1)
							if expertNum != "" {
								expertNumArr = append(expertNumArr, expertNum)
								rightIndex = rightIndex
								expertContentStr := expertContent[rightIndex:]
								expertContentStr = strings.Replace(expertContentStr, "）", "", -1)
								expertContentStr = strings.TrimLeft(expertContentStr, "：")
								expertContentStr = strings.TrimRight(expertContentStr, "（推荐")
								expertContentArr = append(expertContentArr, expertContentStr)
								return
							}
						}
					}
				}

				if strings.Contains(spanText, "访谈时间") {
					spanText = strings.Replace(spanText, "#访谈时间：", "", -1)
					spanText = strings.Replace(spanText, "访谈时间：", "", -1)
					spanText = strings.Replace(spanText, "\n", "", -1)
					spanText = strings.Replace(spanText, " ", "", -1)
					spanText = strings.Trim(spanText, " ")
					spanText = spanText[:10]
					interviewDate := spanText
					if interviewDate != "" {
						interviewDateArr = append(interviewDateArr, interviewDate)
					}
				}
			})
		})
	}

	var expertNumStr, expertContentStr, interviewDateStr string
	if len(expertNumArr) > 0 {
		expertNumStr = expertNumArr[0]
	}
	if len(expertContentArr) > 0 {
		expertContentStr = expertContentArr[0]
	}

	if len(interviewDateArr) > 0 {
		interviewDateStr = interviewDateArr[0]
	}
	expertNumStr = strings.Replace(expertNumStr, "#：", "", -1)
	err = models.ModifyArticleExpert(articleId, expertNumStr, expertContentStr, interviewDateStr, bodyText)
	if err != nil {
		fmt.Println("ModifyArticleExpert Err:" + err.Error())
		return
	}
}
